% Copyright (c) 2018, Voilà Contributors
% Copyright (c) 2018, QuantStack
%
% Distributed under the terms of the BSD 3-Clause License.
%
% The full license is in the file LICENSE, distributed with this software.

(install)=

# Installing Voici

You can install Voici using pip:

```bash
pip install voici
```

If you are using a `requirements.txt` file, you can add the following line:

```bash
# other dependencies
# ...
# add Voici as a dependency
voici
```

If you are using an `environment.yml` file, you can add the dependency under `pip`:

```yaml
- name: voici-demo
  pip:
    - voici
```
